package java.util;

import java.util.function.Supplier;

public final class Objects
{
    private Objects() {
        throw new AssertionError("No java.util.Objects instances for you!");
    }
    
    public static boolean equals(Object o, Object obj) {
        return o == obj || (o != null && o.equals(obj));
    }
    
    public static boolean deepEquals(Object o, Object o2) {
        return o == o2 || (o != null && o2 != null && Arrays.deepEquals0(o, o2));
    }
    
    public static int hashCode(Object o) {
        return (o != null) ? o.hashCode() : 0;
    }
    
    public static int hash(Object... array) {
        return Arrays.hashCode(array);
    }
    
    public static String toString(Object obj) {
        return String.valueOf(obj);
    }
    
    public static String toString(Object o, String s) {
        return (o != null) ? o.toString() : s;
    }
    
    public static <T> int compare(T t, T t2, Comparator<? super T> comparator) {
        return (t == t2) ? 0 : comparator.compare(t, t2);
    }
    
    public static <T> T requireNonNull(T t) {
        if (t == null) {
            throw new NullPointerException();
        }
        return t;
    }
    
    public static <T> T requireNonNull(T t, String s) {
        if (t == null) {
            throw new NullPointerException(s);
        }
        return t;
    }
    
    public static boolean isNull(Object o) {
        return o == null;
    }
    
    public static boolean nonNull(Object o) {
        return o != null;
    }
    
    public static <T> T requireNonNull(T t, Supplier<String> supplier) {
        if (t == null) {
            throw new NullPointerException((String)supplier.get());
        }
        return t;
    }
}
